]> git.cameronkatri.com Git - mandoc.git/blobdiff - man.c
simple implementation of the roff(7) .als (macro alias) request,
[mandoc.git] / man.c
diff --git a/man.c b/man.c
index c52edd4541ecd622d303171eb3ba4d726e9d0e09..f2ba1bdbdd4c45561634a762cff8e57f7cab6dde 100644 (file)
--- a/man.c
+++ b/man.c
@@ -1,4 +1,4 @@
-/*     $Id: man.c,v 1.173 2017/05/08 20:33:53 schwarze Exp $ */
+/*     $Id: man.c,v 1.174 2017/06/03 15:55:24 schwarze Exp $ */
 /*
  * Copyright (c) 2008, 2009, 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
  * Copyright (c) 2013, 2014, 2015, 2017 Ingo Schwarze <schwarze@openbsd.org>
@@ -89,14 +89,15 @@ man_ptext(struct roff_man *man, int line, char *buf, int offs)
                /* Skip leading whitespace. */ ;
 
        /*
* Blank lines are ignored right after headings
* but add a single vertical space elsewhere.
         */
 
        if (buf[i] == '\0') {
-               man_breakscope(man, ROFF_sp);
-               /* Allocate a blank entry. */
-               if (man->last->tok != MAN_SH &&
+               if (man->flags & (MAN_ELINE | MAN_BLINE))
+                       mandoc_msg(MANDOCERR_BLK_BLANK, man->parse,
+                           line, 0, NULL);
+               else if (man->last->tok != MAN_SH &&
                    man->last->tok != MAN_SS) {
                        roff_elem_alloc(man, line, offs, ROFF_sp);
                        man->next = ROFF_NEXT_SIBLING;
@@ -89,14 +89,15 @@ man_ptext(struct roff_man *man, int line, char *buf, int offs)
 
        /*
-        * Blank lines are ignored right after headings
-        * but add a single vertical space elsewhere.
+        * Blank lines are ignored in next line scope and right
+        * after headings but add a single vertical space elsewhere.
         */
 